<?php

/*
Plugin Name: GD Press Tools
Plugin URI: http://www.dev4press.com/plugins/gd-press-tools/
Description: This is collection of administration tools.
Version: 1.2.0
Author: Milan Petrovic
Author URI: http://www.dev4press.com/

== Copyright ==

Copyright 2008 Milan Petrovic (email : milan@gdragon.info)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

require_once(dirname(__FILE__)."/config.php");
require_once(dirname(__FILE__)."/code/defaults.php");
require_once(dirname(__FILE__)."/code/functions.php");
require_once(dirname(__FILE__)."/code/db.php");
require_once(dirname(__FILE__)."/gdragon/gd_debug.php");
require_once(dirname(__FILE__)."/gdragon/gd_db_install.php");
require_once(dirname(__FILE__)."/gdragon/gd_functions.php");

if (!class_exists('GDPressTools')) {
    class GDPressTools {
        var $wp_version;
        var $plugin_url;
        var $plugin_path;
        var $admin_plugin;
        var $admin_plugin_page;
        var $o;
        var $l;

        var $status = "";
        var $script = "";

        var $default_options;

        function GDPressTools() {
            $gdd = new GDPTDefaults();
            $this->default_options = $gdd->default_options;
            define('PRESSTOOLS_INSTALLED', $this->default_options["version"]." ".$this->default_options["status"]);

            $this->plugin_path_url();
            $this->install_plugin();
            $this->actions_filters();
            if (PRESSTOOLS_PHP_SETTINGS) $this->php_ini();

            if ($this->o["revisions_to_save"] != -1) gd_set_revisions($this->o["revisions_to_save"]);
            define("PRESSTOOLS_DEBUG_SQL", $this->o["debug_sql"] == 1);
        }

        function get($setting) {
            return $this->o[$setting];
        }

        function php_ini() {
            if ($this->o["php_memory_limit_enabled"] == 1)
                @ini_set('memory_limit', $this->o["php_memory_limit"]);
        }

        function add_dashboard_widget() {
            if (!function_exists('wp_add_dashboard_widget'))
                wp_register_sidebar_widget("dashboard_gdpresstools", "GD Press Tools", array(&$this, 'display_dashboard_widget'), array('all_link' => get_bloginfo('wpurl').'/wp-admin/admin.php?page=gd-press-tools/gd-press-tools.php', 'width' => 'half', 'height' => 'single'));
            else
                wp_add_dashboard_widget("dashboard_gdpresstools", "GD Press Tools", array(&$this, 'display_dashboard_widget'));
        }

        function add_dashboard_widget_filter($widgets) {
            global $wp_registered_widgets;

            if (!isset($wp_registered_widgets["dashboard_gdpresstools"])) return $widgets;

            array_splice($widgets, 2, 0, "dashboard_gdpresstools");
            return $widgets;
        }

        function display_dashboard_widget($sidebar_args) {
            if (!function_exists('wp_add_dashboard_widget')) {
                extract($sidebar_args, EXTR_SKIP);
                echo $before_widget.$before_title.$widget_name.$after_title;
            }
            $options = $this->o;
            include($this->plugin_path.'modules/dashboard.php');
            if (!function_exists('wp_add_dashboard_widget')) {
                echo $after_widget;
            }
        }

        function install_plugin() {
            global $wp_version;
            $this->wp_version = substr(str_replace('.', '', $wp_version), 0, 2);

            $this->o = get_option('gd-press-tools');

            if (!is_array($this->o)) {
                $this->default_options["memory_limit"] = ini_get('memory_limit');
                update_option('gd-press-tools', $this->default_options);
                $this->o = get_option('gd-press-tools');
            }

            if ($this->o["build"] < $this->default_options["build"]) {
                $this->o = gdFunctionsGDPT::upgrade_settings($this->o, $this->default_options);

                gdDBInstallGDPT::delete_tables(PRESSTOOLS_PATH);
                gdDBInstallGDPT::create_tables(PRESSTOOLS_PATH);
                gdDBInstallGDPT::upgrade_tables(PRESSTOOLS_PATH);
                gdDBInstallGDPT::alter_tables(PRESSTOOLS_PATH);
                $this->o["database_upgrade"] = date("r");

                $this->o["version"] = $this->default_options["version"];
                $this->o["date"] = $this->default_options["date"];
                $this->o["status"] = $this->default_options["status"];
                $this->o["build"] = $this->default_options["build"];

                update_option('gd-press-tools', $this->o);
            }

            $this->script = $_SERVER["PHP_SELF"];
            $this->script = end(explode("/", $this->script));
        }

        function plugin_path_url() {
            if ($this->wp_version < 26) {
                $this->plugin_url = get_option('siteurl').'/'.PLUGINDIR.'/gd-press-tools/';
            }
            else {
                $this->plugin_url = WP_PLUGIN_URL.'/gd-press-tools/';
            }
            $this->plugin_path = dirname(__FILE__)."/";

            define('PRESSTOOLS_URL', $this->plugin_url);
            define('PRESSTOOLS_PATH', $this->plugin_path);
        }

        function disable_flash_uploader(){
            return false;
        }

        function actions_filters() {
            add_action('init', array(&$this, 'init'));
            add_action('admin_init', array(&$this, 'admin_init'));
            add_action('admin_menu', array(&$this, 'admin_menu'));
            add_action('admin_head', array(&$this, 'admin_head'));
            add_action('in_admin_footer', array(&$this, 'admin_footer'));
            add_action('after_plugin_row_gd-press-tools/gd-press-tools.php', array(&$this,'plugin_check_version'), 10, 2);
            add_filter('plugin_action_links', array(&$this, 'plugin_links'), 10, 2 );
            add_filter('the_content', array(&$this, 'count_views'));

            if ($this->o["disable_flash_uploader"] == 1)
                add_filter('flash_uploader', array(&$this, 'disable_flash_uploader'), 5);
            if ($this->o["updates_disable_core"] == 1)
                add_filter('pre_option_update_core', create_function('$update_core', "return null;"));
            if ($this->o["updates_disable_plugins"] == 1)
                add_filter('pre_option_update_plugins', create_function('$update_core', "return null;"));

            if ($this->o["integrate_dashboard"] == 1) {
                add_action('wp_dashboard_setup', array(&$this, 'add_dashboard_widget'));
                if (!function_exists('wp_add_dashboard_widget'))
                    add_filter('wp_dashboard_widgets', array(&$this, 'add_dashboard_widget_filter'));
            }

            add_action('manage_posts_columns', array(&$this, 'admin_post_columns'));
            add_action('manage_pages_columns', array(&$this, 'admin_post_columns'));
            add_action('manage_media_columns', array(&$this, 'admin_media_columns'));
            add_action('manage_link-manager_columns', array(&$this, 'admin_links_columns'));
            add_action('manage_posts_custom_column', array(&$this, 'admin_columns_data'), 10, 2);
            add_action('manage_pages_custom_column', array(&$this, 'admin_columns_data'), 10, 2);
            add_action('manage_media_custom_column', array(&$this, 'admin_columns_data'), 10, 2);
            add_action('manage_link_custom_column', array(&$this, 'admin_columns_data'), 10, 2);

            if (is_admin() && $this->script == "edit.php" && $this->o["integrate_post_per_page"] > 0) add_action("pre_get_posts", array(&$this, 'admin_pre_get_posts'), 10, 1);
        }

        function count_views($content) {
            global $post, $userdata;

            if ($this->o["posts_views_tracking"] == 1) {
                if ((is_single() && $this->o["posts_views_tracking_posts"] == 1) ||
                    (is_page() && $this->o["posts_views_tracking_pages"] == 1)) {
                    $users = explode(",", $this->o["posts_views_tracking_ignore"]);
                    if (($userdata->ID == 0 && $this->o["posts_views_tracking_visitors"] == 1) ||
                        ($userdata->ID > 0 && $this->o["posts_views_tracking_users"] == 1 && !in_array($userdata->ID, $users))) {
                        GDPTDB::insert_posts_views($post->ID, $userdata->ID > 0);
                    }
                }
            }

            if ($this->o["users_tracking"] == 1 && $userdata->ID > 0) {
                if ((is_single() && $this->o["users_tracking_posts"] == 1) ||
                    (is_page() && $this->o["users_tracking_pages"] == 1)) {
                    $users = explode(",", $this->o["users_tracking_ignore"]);
                    if (!in_array($userdata->ID, $users)) {
                        GDPTDB::insert_users_tracking($post->ID, $userdata->ID);
                    }
                }
            }

            return $content;
        }

        function plugin_links($links, $file) {
            static $this_plugin;
            if (!$this_plugin) $this_plugin = plugin_basename(__FILE__);

            if ($file == $this_plugin ){
                $settings_link = '<a href="admin.php?page=gd-press-tools-settings">'.__("Settings", "gd-press-tools").'</a>';
                array_unshift($links, $settings_link);
            }
            return $links;
        }

        function plugin_check_version($file, $plugin_data) {
            $current = get_option('update_plugins');
            if (!isset($current->response[$file])) return false;

            $columns = $this->wp_version < 28 ? 5 : 3;
            $url = gdFunctionsGDPT::get_update_url($this->o, get_option('home'));
            $update = wp_remote_fopen($url);
            echo '<td colspan="'.$columns.'" class="gdr-plugin-update">';
            echo $update;
            echo '</td>';
        }

        function admin_footer() {
            _e("Thank you for using", "gd-press-tools");
            echo ' <a target="_blank" href="http://www.dev4press.com/plugins/gd-press-tools/">GD Press Tools '.$this->o["version"].'</a> ';
            _e("administration addon plugin", "gd-press-tools");
            echo '.<br/>';
        }

        function admin_media_columns($columns) {
            $new_columns = array();
            if ($this->get("integrate_media_id") == 1) {
                $i = 0;
                foreach ($columns as $key => $value) {
                    if ($i == 1) $new_columns["gdpt_mediaid"] = "ID";
                    $new_columns[$key] = $value;
                    $i++;
                }
            }
            else $new_columns = $columns;
            return $new_columns;
        }

        function admin_links_columns($columns) {
            $new_columns = array();
            if ($this->get("integrate_links_id") == 1) {
                $i = 0;
                foreach ($columns as $key => $value) {
                    if ($i == 1) $new_columns["gdpt_linksid"] = "ID";
                    $new_columns[$key] = $value;
                    $i++;
                }
            }
            else $new_columns = $columns;
            return $new_columns;
        }

        function admin_post_columns($columns) {
            $new_columns = array();
            if ($this->get("integrate_post_id") == 1) {
                $i = 0;
                foreach ($columns as $key => $value) {
                    if ($i == 1) $new_columns["gdpt_postid"] = "ID";
                    $new_columns[$key] = $value;
                    $i++;
                }
            }
            else $new_columns = $columns;
            if ($this->get("integrate_post_revisions") == 1) $new_columns["gdpt_revisions"] = __("Revisions", "gd-press-tools");
            if ($this->get("integrate_post_sticky") == 1) $new_columns["gdpt_sticky"] = __("Sticky", "gd-press-tools");
            return $new_columns;
        }

        function admin_columns_data($column, $id) {
            $url = add_query_arg("gda", "delrev", $_SERVER['REQUEST_URI']);
            $url = add_query_arg("pid", $id, $url);
            switch ($column) {
                case "gdpt_sticky":
                    if (is_sticky($id)) echo __("Yes", "gd-press-tools");
                    break;
                case "gdpt_mediaid":
                case "gdpt_postid":
                case "gdpt_linksid":
                    echo $id;
                    break;
                case "gdpt_revisions":
                    $counter = gd_count_revisions($id);
                    if ($counter > 0) {
                        echo $counter.": ";
                        echo '<a href="'.$url.'" onclick="if (confirm(\''.__("Are you sure that you want to delete revisions for this post?", "gd-press-tools").'\')) { return true; } return false;" class="submitdelete deletion">Delete</a>';
                    }
                    else echo '0';
                    break;
            }
        }

        function require_login() {
            if (!is_user_logged_in() && strpos($_SERVER['PHP_SELF'], 'wp-login.php') === false && strpos($_SERVER['PHP_SELF'], 'wp-register.php') === false)
                auth_redirect();
        }

        function init() {
            $this->l = get_locale();
            if(!empty($this->l)) {
                $moFile = dirname(__FILE__)."/languages/gd-press-tools-".$this->l.".mo";
                if (@file_exists($moFile) && is_readable($moFile)) load_textdomain('gd-press-tools', $moFile);
            }

            if ($this->o["rss_disable"] == 1) {
                add_action('do_feed', 'gd_disable_feed', 1);
                add_action('do_feed_rdf', 'gd_disable_feed', 1);
                add_action('do_feed_rss', 'gd_disable_feed', 1);
                add_action('do_feed_rss2', 'gd_disable_feed', 1);
                add_action('do_feed_atom', 'gd_disable_feed', 1);
            }
            if ($this->o["updates_disable_core"] == 1)
                remove_action('init', 'wp_version_check');
            if ($this->o["updates_disable_plugins"] == 1)
                remove_action('init', 'wp_update_plugins');

            if ($this->o["auth_require_login"] == 1)
                $this->require_login();
            if ($this->o["remove_wp_version"] == 1)
                add_filter('the_generator', create_function('$wpv', "return null;"));

            if ($this->o["remove_rds"] == 1 && function_exists('rsd_link') && !is_admin())
                remove_action('wp_head', 'rsd_link');
            if ($this->o["remove_wlw"] == 1 && function_exists('wlwmanifest_link') && !is_admin())
                remove_action('wp_head', 'wlwmanifest_link');
        }

        function admin_init() {
            if (isset($_GET["page"])) {
                if (substr($_GET["page"], 0, 14) == "gd-press-tools") {
                    $this->admin_plugin = true;
                    $this->admin_plugin_page = substr($_GET["page"], 15);
                }
            }

            wp_enqueue_script('jquery');
            wp_enqueue_script('thickbox');
            wp_enqueue_style('thickbox');

            $this->dashboard_operations();
            $this->init_operations();
            $this->settings_operations();

            if ($this->o["updates_disable_plugins"] == 1)
                remove_action('admin_init', 'wp_update_plugins');
        }

        function settings_operations() {
            if (isset($_POST['gdpt_saving'])) {
                $this->o["integrate_post_revisions"] = isset($_POST['integrate_post_revisions']) ? 1 : 0;
                $this->o["integrate_post_id"] = isset($_POST['integrate_post_id']) ? 1 : 0;
                $this->o["integrate_post_sticky"] = isset($_POST['integrate_post_sticky']) ? 1 : 0;
                $this->o["integrate_dashboard"] = isset($_POST['integrate_dashboard']) ? 1 : 0;
                $this->o["rss_disable"] = isset($_POST['rss_disable']) ? 1 : 0;
                $this->o["updates_disable_core"] = isset($_POST['updates_disable_core']) ? 1 : 0;
                $this->o["updates_disable_plugins"] = isset($_POST['updates_disable_plugins']) ? 1 : 0;
                $this->o["auth_require_login"] = isset($_POST['auth_require_login']) ? 1 : 0;
                $this->o["remove_wp_version"] = isset($_POST['remove_wp_version']) ? 1 : 0;
                $this->o["remove_rds"] = isset($_POST['remove_rds']) ? 1 : 0;
                $this->o["remove_wlw"] = isset($_POST['remove_wlw']) ? 1 : 0;
                $this->o["integrate_media_id"] = isset($_POST['integrate_media_id']) ? 1 : 0;
                $this->o["integrate_links_id"] = isset($_POST['integrate_links_id']) ? 1 : 0;
                $this->o["debug_sql"] = isset($_POST['debug_sql']) ? 1 : 0;
                $this->o["disable_flash_uploader"] = isset($_POST['disable_flash_uploader']) ? 1 : 0;

                $this->o["posts_views_tracking"] = isset($_POST['posts_views_tracking']) ? 1 : 0;
                $this->o["posts_views_tracking_posts"] = isset($_POST['posts_views_tracking_posts']) ? 1 : 0;
                $this->o["posts_views_tracking_pages"] = isset($_POST['posts_views_tracking_pages']) ? 1 : 0;
                $this->o["posts_views_tracking_visitors"] = isset($_POST['posts_views_tracking_visitors']) ? 1 : 0;
                $this->o["posts_views_tracking_users"] = isset($_POST['posts_views_tracking_users']) ? 1 : 0;
                $this->o["users_tracking"] = isset($_POST['users_tracking']) ? 1 : 0;
                $this->o["users_tracking_posts"] = isset($_POST['users_tracking_posts']) ? 1 : 0;
                $this->o["users_tracking_pages"] = isset($_POST['users_tracking_pages']) ? 1 : 0;
                $this->o["posts_views_tracking_ignore"] = $_POST['posts_views_tracking_ignore'];
                $this->o["users_tracking_ignore"] = $_POST['users_tracking_ignore'];

                $this->o["integrate_post_per_page"] = $_POST['integrate_post_per_page'];
                $this->o["revisions_to_save"] = $_POST['revisions_to_save'];
                $this->o["autosave_period"] = $_POST['autosave_period'];

                $this->o["php_memory_limit"] = $_POST['php_memory_limit'];
                $this->o["php_memory_limit_enabled"] = isset($_POST['php_memory_limit_enabled']) ? 1 : 0;

                update_option("gd-press-tools", $this->o);
                wp_redirect(add_query_arg("settings", "saved"));
                exit();
            }
        }

        function dashboard_operations() {
            if (isset($_GET["gdpt"])) {
                $opr = $_GET["gdpt"];
                switch ($opr) {
                    case "delrev":
                        $counter = gd_delete_all_revisions();
                        $this->o["counter_total_revisions"]+= $counter;
                        $this->o["tool_revisions_removed"] = date("r");
                        update_option("gd-press-tools", $this->o);
                        break;
                    case "cledtb":
                        gd_optimize_db();
                        break;
                }
                wp_redirect("index.php");
                exit();
            }
        }

        function init_operations() {
            $gd_action = $_GET["gda"];
            if ($gd_action != '') {
                switch ($gd_action) {
                    case "unsevt":
                        wp_unschedule_event($_GET['time'], $_GET['job']);
                        wp_redirect(remove_query_arg(array('time', 'job', 'gda'), stripslashes($_SERVER['REQUEST_URI'])));
                        exit();
                        break;
                    case "delrev":
                        $post_id = $_GET["pid"];
                        $counter = gd_delete_revisions($post_id);
                        $this->o["counter_total_revisions"]+= $counter;
                        wp_redirect(remove_query_arg(array('pid', 'gda'), stripslashes($_SERVER['REQUEST_URI'])));
                        exit();
                        break;
                    case "tpldrp":
                        $table = $_GET["name"];
                        gd_db_table_drop($table);
                        wp_redirect(remove_query_arg(array('name', 'gda'), stripslashes($_SERVER['REQUEST_URI'])));
                        exit();
                        break;
                    case "tblemp":
                        $table = $_GET["name"];
                        gd_db_table_empty($table);
                        wp_redirect(remove_query_arg(array('name', 'gda'), stripslashes($_SERVER['REQUEST_URI'])));
                        exit();
                        break;
                }
            }

            if (isset($_POST['gdpt_revisions_delete'])) {
                $counter = gd_delete_all_revisions();
                $this->o["counter_total_revisions"]+= $counter;
                $this->o["tool_revisions_removed"] = date("r");
                update_option("gd-press-tools", $this->o);
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_cmm_set'])) {
                $cmm_date = $_POST["gdpt_cmm_date"];
                $cmm_comments = isset($_POST["gdpt_cmm_comments"]) ? 1 : 0;
                $cmm_pings = isset($_POST["gdpt_cmm_pings"]) ? 1 : 0;
                GDPTDB::set_posts_comments_status($cmm_date, $cmm_comments, $cmm_pings);
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_db_clean'])) {
                gd_optimize_db();
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_admin_rss_cache_reset'])) {
                gd_clear_rss_cache();
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_admin_widget_reset'])) {
                gd_reset_widgets();
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_admin_rename'])) {
                $this->status = GDPTDB::rename_account($_POST['gdpt_admin_username']);
                if ($this->status == "OK");
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_admin_folder_protect'])) {
                gd_create_protection_files();
                wp_redirect($_SERVER['REQUEST_URI']);
                exit;
            }

            if (isset($_POST['gdpt_posts_delete'])) {
                $results = GDPTDB::delete_posts($_POST['gdpt_delposts_date']);
                $this->status = sprintf(__("Deleted %s posts and %s comments.", "gd-press-tools"), $results["posts"], $results["comments"]);
            }
        }

        function admin_menu() {
            if ($this->wp_version < 27)
                add_menu_page('GD Press Tools', 'GD Press Tools', 10, __FILE__, array(&$this,"admin_tool_front"));
            else
                add_menu_page('GD Press Tools', 'GD Press Tools', 10, __FILE__, array(&$this,"admin_tool_front"), plugins_url('gd-press-tools/gfx/menu.png'));

            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Front Page", "gd-press-tools"), __("Front Page", "gd-press-tools"), 10, __FILE__, array(&$this,"admin_tool_front"));
            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Enviroment Info", "gd-press-tools"), __("Enviroment Info", "gd-press-tools"), 10, "gd-press-tools-server", array(&$this,"admin_tool_server"));
            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Administration", "gd-press-tools"), __("Administration", "gd-press-tools"), 10, "gd-press-tools-admin", array(&$this,"admin_tool_admin"));
            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Posts", "gd-press-tools"), __("Posts", "gd-press-tools"), 10, "gd-press-tools-posts", array(&$this,"admin_tool_posts"));
            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Database", "gd-press-tools"), __("Database", "gd-press-tools"), 10, "gd-press-tools-database", array(&$this,"admin_tool_database"));
            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Cron Scheduler", "gd-press-tools"), __("Cron Scheduler", "gd-press-tools"), 10, "gd-press-tools-cron", array(&$this,"admin_tool_cron"));
            add_submenu_page(__FILE__, 'GD Press Tools: '.__("Settings", "gd-press-tools"), __("Settings", "gd-press-tools"), 10, "gd-press-tools-settings", array(&$this,"admin_tool_settings"));

            if ($this->o["updates_disable_plugins"] == 1)
                remove_action('load-plugins.php', 'wp_update_plugins');
        }

        function admin_pre_get_posts($wpq) {
            $wpq->set("posts_per_page", $this->o["integrate_post_per_page"]);
            return $wpq;
        }

        function admin_head() {
            if ($this->admin_plugin) {
                wp_admin_css('css/dashboard');
                $datepicker_date = date("Y, n, j");
                echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/admin_main.css" type="text/css" media="screen" />');
                if ($this->wp_version >= 28) echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/admin_wp28.css" type="text/css" media="screen" />');
                else if ($this->wp_version >= 27 && $this->wp_version < 28) echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/admin_wp27.css" type="text/css" media="screen" />');
                else echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/admin_wp26.css" type="text/css" media="screen" />');
                echo('<script type="text/javascript" src="'.$this->plugin_url.'js/jquery-ui.js"></script>');
                echo('<script type="text/javascript" src="'.$this->plugin_url.'js/jquery-ui-tabs.js"></script>');
                echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/jquery/ui.tabs.css" type="text/css" media="screen" />');
                echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/jquery/ui.core.css" type="text/css" media="screen" />');
                echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/jquery/ui.theme.css" type="text/css" media="screen" />');
                echo('<script type="text/javascript" src="'.$this->plugin_url.'js/jquery-ui-datepicker.js"></script>');
                echo('<script type="text/javascript" src="'.$this->plugin_url.'js/press-tools.js"></script>');
                include($this->plugin_path."/code/js.php");
            }
            echo('<link rel="stylesheet" href="'.$this->plugin_url.'css/admin.css" type="text/css" media="screen" />');
            echo('<script type="text/javascript" src="'.$this->plugin_url.'js/dashboard.js"></script>');
            echo('<!--[if IE]><link rel="stylesheet" href="'.$this->plugin_url.'css/admin_ie.css" type="text/css" media="screen" /><![endif]-->');
        }

        function admin_tool_front() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/front.php');
        }

        function admin_tool_server() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/server.php');
        }

        function admin_tool_cron() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/cron.php');
        }

        function admin_tool_admin() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/admin.php');
        }

        function admin_tool_posts() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/posts.php');
        }

        function admin_tool_database() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/db.php');
        }

        function admin_tool_settings() {
            $options = $this->o;
            $status = $this->status;
            include($this->plugin_path.'modules/settings.php');
        }
    }

    $gdpt_debug = new gdDebugGDPT(PRESSTOOLS_LOG_PATH);
    $gdpt = new GDPressTools();

    /**
    * Writes a object dump into the log file
    *
    * @param string $msg log entry message
    * @param mixed $object object to dump
    * @param string $block adds start or end dump limiters { none | start | end }
    * @param string $mode file open mode
    */
    function wp_gdpt_dump($msg, $obj, $block = "none", $mode = "a+") {
        if (PRESSTOOLS_DEBUG_ACTIVE) {
            global $gdpt_debug;
            $gdpt_debug->dump($msg, $obj, $block, $mode);
        }
    }

    /**
    * Writes a object dump into the log file if the sql logging is active
    *
    * @param string $msg log entry message
    * @param mixed $object object to dump
    * @param string $block adds start or end dump limiters { none | start | end }
    * @param string $mode file open mode
    */
    function wp_gdpt_log_sql($msg, $obj, $block = "none", $mode = "a+") {
        if (PRESSTOOLS_DEBUG_SQL) wp_gdpt_dump($msg, $obj, $block, $mode);
    }
}

?>
